@@ -15,7 +15,7 @@ use base 'DynaLoader';
 use base 'Exporter';
 use vars qw(@EXPORT %EXPORT_TAGS $VERSION);
 
-$VERSION = '1.07';
+$VERSION = '1.08';
 @EXPORT = qw(
 	FSpGetCatInfo
 	FSpSetCatInfo
@@ -1606,12 +1606,43 @@ if ($^O ne 'MacOS') {
 	*NAMFFP = *NewAliasMinimalFromFullPath{CODE};
 	no strict 'refs';
 	no warnings 'redefine'; 
-	require Mac::Path::Util;
 	*NewAliasMinimalFromFullPath = sub {
-		NAMFFP(Mac::Path::Util->new($_[0], { type => Mac::Path::Util::DARWIN() })->mac_path);
+		NAMFFP(_Unix2Mac($_[0]));
 	}
 }
 
+sub _Unix2Mac {
+	require MacPerl;
+	my($unix) = @_;
+	my $mac;
+
+	# is this a relative url?
+	if (substr($unix, 0, 1) ne '/') {
+		$unix =~ tr|/:|:/|;
+		$mac = ':' . $unix;
+	}
+
+	# is this an absolute url with another Volume?
+	elsif ($unix =~ m|^/Volumes/([^/]+)(/.*)|) {
+		my $volume = $1;
+		my $path   = $2;
+
+		$path =~ tr|/:|:/|;
+		$mac = $volume . $path;
+	}
+
+	# absolute path off of startup volume
+	elsif (substr($unix, 0, 1) eq '/') {
+		(my $volume = scalar MacPerl::Volumes()) =~ s/^.+?:(.+)$/$1/;
+
+		$unix =~ tr|/:|:/|;
+		$mac = $volume . $unix;
+	}
+
+	return $mac;
+}
+
+
 =include Files.xs
 
 =head1 AUTHOR
